@@ -41,8 +41,8 @@ class ARC2_StoreAskQueryHandler extends ARC2_StoreSelectQueryHandler {
   
   function getFinalQueryResult($q_sql, $tmp_tbl) {
     $con = $this->store->getDBCon();
-    $rs = mysql_query('SELECT success FROM ' . $tmp_tbl, $con);
-    $r = ($row = mysql_fetch_array($rs)) ? $row['success'] : 0;
+    $rs = mysqli_query( $con, 'SELECT success FROM ' . $tmp_tbl);
+    $r = ($row = mysqli_fetch_array($rs)) ? $row['success'] : 0;
     return $r ? true : false;
   }
 
